@@ -3,10 +3,10 @@
     korean.morphology.substantive
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    :copyright: (c) 2012 by Heungsub Lee
+    :copyright: (c) 2012-2013 by Heungsub Lee
     :license: BSD, see LICENSE for more details.
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 import re
 
 from .morpheme import Morpheme
@@ -24,12 +24,12 @@ class Substantive(Morpheme):
         after the substantive string using particle format spec such as
         ``{0:은}`` or ``{1:로}``:
 
-            >>> format(Noun(u'엄마'), u'을')
-            u'엄마를'
-            >>> u'{0:은} {1:로}'.format(Noun(u'아들'), Noun(u'마을'))
-            u'아들은 마을로'
-            >>> u'{0:은} {1:로}'.format(Noun(u'아들'), Noun(u'산'))
-            u'아들은 산으로'
+            >>> format(Noun('엄마'), '을')
+            '엄마를'
+            >>> '{0:은} {1:로}'.format(Noun('아들'), Noun('마을'))
+            '아들은 마을로'
+            >>> '{0:은} {1:로}'.format(Noun('아들'), Noun('산'))
+            '아들은 산으로'
         """
         from .particle import Particle
         from . import merge
@@ -53,8 +53,8 @@ class Noun(Substantive):
     def read(self):
         """Reads a noun as Korean. The result will be Hangul.
 
-            >>> Noun(u'레벨42').read()
-            u'레벨사십이'
+            >>> Noun('레벨42').read()
+            '레벨사십이'
         """
         rv = []
         for match in self.READING_PATTERN.finditer(unicode(self)):
@@ -78,9 +78,9 @@ class NumberWord(Substantive):
         """Reads number as Korean.
 
             >>> NumberWord(1234567890).read()
-            u'십이억삼천사백오십육만칠천팔백구십'
+            '십이억삼천사백오십육만칠천팔백구십'
             >>> NumberWord.read_phases(0)
-            u'영'
+            '영'
         """
         return ''.join(type(self).read_phases(self.number))
 
@@ -89,9 +89,9 @@ class NumberWord(Substantive):
         """Reads number as Korean but seperates the result at each 10k.
 
             >>> NumberWord.read_phases(1234567890)
-            (u'십이억', u'삼천사백오십육만', u'칠천팔백구십')
+            ('십이억', '삼천사백오십육만', '칠천팔백구십')
             >>> NumberWord.read_phases(0)
-            (u'영',)
+            ('영',)
         """
         rv, phase = [], []
         digit = 0
@@ -107,7 +107,7 @@ class NumberWord(Substantive):
                     phase.append(cls.__digits__[digit % 4])
                 except KeyError:
                     pass
-            number /= 10
+            number //= 10
             if not single and not number or \
                single == 1 and not digit or single > 1:
                 phase.append(cls.__numbers__[single])
@@ -115,7 +115,7 @@ class NumberWord(Substantive):
                 if digit < 4 or len(phase) > 1:
                     rv.append(''.join(phase[::-1]))
                 else:
-                    rv.append(u'')
+                    rv.append('')
                 phase = []
                 if not number:
                     break
@@ -136,6 +136,8 @@ class Loanword(Substantive):
     """A class for loanword that is called "외래어" in Korean. This depends
     on `Hangulize <http://packages.python.org/hangulize>`_ which automatically
     transcribes a non-Korean word into Hangul.
+
+    .. versionadded:: 0.1.4
     """
 
     def _import_hangulize(self):
@@ -159,12 +161,12 @@ class Loanword(Substantive):
         """Transcribes into Hangul using `Hangulize
         <http://packages.python.org/hangulize>`_.
 
-        >>> Loanword(u'Guido van Rossum', 'nld').read()
-        u'히도 판로쉼'
-        >>> Loanword(u'საქართველო', 'kat').read()
-        u'사카르트벨로'
-        >>> Loanword(u'Leonardo da Vinci', 'ita').read()
-        u'레오나르도 다 빈치'
+        >>> Loanword('Guido van Rossum', 'nld').read()
+        '히도 판로쉼'
+        >>> Loanword('საქართველო', 'kat').read()
+        '사카르트벨로'
+        >>> Loanword('Leonardo da Vinci', 'ita').read()
+        '레오나르도 다 빈치'
         """
         hangulize = self._import_hangulize()
         return hangulize.hangulize(self.basic(), lang=self.lang)
